# Generated by Django 2.2.4 on 2019-08-23 13:04

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('common', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
            ],
            options={
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
            },
        ),
        migrations.CreateModel(
            name='Supplier',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='Name')),
                ('nif', models.CharField(blank=True, max_length=50, null=True, verbose_name='NIF Number')),
                ('keywords', models.CharField(blank=True, max_length=200, null=True, verbose_name='Keywords')),
                ('contact', models.CharField(blank=True, max_length=200, null=True, verbose_name='Contact person')),
                ('phone', models.CharField(blank=True, max_length=200, null=True, verbose_name='Phone Number')),
                ('email', models.CharField(blank=True, max_length=200, null=True, verbose_name='Email')),
                ('discounts', models.CharField(blank=True, max_length=200, null=True, verbose_name='Discounts')),
                ('category', models.ManyToManyField(blank=True, to='suppliers.Category')),
                ('country', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='common.Country')),
            ],
            options={
                'verbose_name': 'Supplier',
                'verbose_name_plural': 'Suppliers',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Tophistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('top', models.CharField(max_length=100, verbose_name='TOP')),
                ('date', models.DateField(blank=True, null=True, verbose_name='Date')),
                ('createdby', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('supplier', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='suppliers.Supplier')),
            ],
            options={
                'verbose_name': 'TOP History',
                'verbose_name_plural': 'Top Histories',
            },
        ),
    ]



from django.db import models
from .history import Tophistory


class Supplier(models.Model):
    """
    Represents a Supplier in the systemcurrency
    """
    name      = models.CharField('Name', max_length=200)
    nif       = models.CharField('NIF Number', max_length=50, blank=True, null=True)
    keywords  = models.CharField('Keywords', max_length=200, blank=True, null=True)
    contact   = models.CharField('Contact person', max_length=200, blank=True, null=True)
    phone     = models.CharField('Phone Number', max_length=200, blank=True, null=True)
    email     = models.CharField('Email', max_length=200, blank=True, null=True)
    discounts = models.CharField('Discounts', max_length=200, blank=True, null=True)

    country  = models.ForeignKey('common.Country', blank=True, null=True, on_delete=models.CASCADE)
    category = models.ManyToManyField('Category', blank=True)

    @staticmethod
    def autocomplete_search_fields():
        return ("name__icontains", "keywords__icontains")

    class Meta:
        verbose_name = "Supplier"
        verbose_name_plural = "Suppliers"
        ordering = ['name',]

    def __str__(self):
        return self.name

    def top(self):
        """
        The function will order the top Histories payment in the finance page according to their creation order
        so the last top in this page his the last created top
        In the admin list of suppliers we will see the last created top
        """
        return Tophistory.objects.filter(supplier=self).order_by('-pk').first()

    def categories_str(self):
        """
        The function will present all the categories for this finance in one line
        in the admin list of suppliers
        """
        return ", ".join([str(cat) for cat in self.category.all()])



from pyforms_web.widgets.django import ModelAdminWidget
from pyforms_web.widgets.django import ModelFormWidget
from pyforms.basewidget import segment
from django.conf import settings
from confapp     import conf
from suppliers.models import Supplier
from pyforms.controls import ControlButton
from pyforms.controls import ControlText
from suppliers.models import Category

class SupplierFormAdmin(ModelFormWidget):

    MODEL = Supplier  #model to manage
    TITLE = 'Suppliers'  #title of the application

    #formset of the edit form
    FIELDSETS = [
        (
            segment(
                ('name','nif'),
                ('email','contact'),
                ('country','phone'),
            ),
            segment(
                'keywords',
                'discounts',
                'category',
                ('_category','_addcategory_btn')
            )
        )
    ]

    AUTHORIZED_GROUPS = ['superuser', settings.APP_PROFILE_ORDERS]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self._addcategory_btn = ControlButton(
            '<i class="icon plus" ></i>Category',
            css='basic mini',
            field_css='five wide',
            label_visible=False,
            default=self.__create_new_category,
        )
        self._category = ControlText(
            'New category', 
            field_css='eleven wide',
            label_visible=False,
            visible=False
        )


    def __create_new_category(self):
        
        if self._category.visible is False:
            self._category.show()
            self._addcategory_btn.label = '<i class="icon file outline" ></i>Create'
            self._addcategory_btn.css = 'blue'
        else:
            self._category.hide()
            self._addcategory_btn.label = '<i class="icon plus" ></i>Category'
            self._addcategory_btn.css = 'basic mini'
            if self._category.value:
                obj, created = Category.objects.get_or_create(name=self._category.value)





class SupplierAdminWidget(ModelAdminWidget):
    

    UID   = 'finance-Supplier-app'.lower()
    MODEL = Supplier
    
    TITLE = 'Suppliers'

    #fields to be used in the search
    SEARCH_FIELDS  = ['supplier_name__icontains']
    EDITFORM_CLASS = SupplierFormAdmin    #edit form class
    
    ########################################################
    #### ORQUESTRA CONFIGURATION ###########################
    ########################################################
    LAYOUT_POSITION      = conf.ORQUESTRA_HOME
    ORQUESTRA_MENU       = 'left'
    ORQUESTRA_MENU_ORDER = 0
    ORQUESTRA_MENU_ICON  = 'truck'
    #AUTHORIZED_GROUPS   = ['superuser'] #groups with authorization to visualize the app
    ########################################################
    
    
   
    
    


#!/usr/bin/python
# -*- coding: utf-8 -*-

import re
from setuptools import setup, find_packages

version, license = None, None
with open('suppliers/__init__.py', 'r') as fd:
    content = fd.read()
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    license = re.search(r'^__license__\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
if version is None: raise RuntimeError('Cannot find version information')
if license is None: raise RuntimeError('Cannot find license information')

with open('README.md', 'r') as fd:
    long_description = fd.read()

setup(
    name='core-suppliers',
    version=version,
    description='Research CORE ERM - suppliers module',
    author='Ricardo Ribeiro, Hugo Cachitas',
    author_email='ricardojvr@gmail.com, hugo.cachitas@research.fchampalimaud.org',
    url='https://github.com/research-core/core-suppliers',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    license=license,
)



from django.db import models


class Tophistory(models.Model):
    """
    Represents a historic time of payment of a finance in the system
    """

    top  = models.CharField('TOP', max_length=100)
    date = models.DateField('Date', blank=True, null=True)

    createdby = models.ForeignKey('auth.User', blank=True, null=True, on_delete=models.CASCADE)
    supplier  = models.ForeignKey('Supplier', blank=True, null=True, on_delete=models.CASCADE)

    class Meta:
        verbose_name = "TOP History"
        verbose_name_plural = "Top Histories"

    def __str__(self):
        return self.top



from django.db import models


class Category(models.Model):
    """
    Represents Product Category in the system
    """
    name = models.CharField('Name', max_length=100, unique=True) #: Name

    class Meta:
        verbose_name = "Category"
        verbose_name_plural = "Categories"

    def __str__(self):
        return self.name

    
    @staticmethod
    def autocomplete_search_fields():
        return ("name__icontains",)
